Commands

Enum Commands 

pub enum Commands {
    Select {
        choose_template: bool,
        no_project_detect: bool,
        config: Option<PathBuf>,
    },
    Connect {
        path: PathBuf,
        template: Option<String>,
        session_name: Option<String>,
        config: Option<PathBuf>,
    },
    Switch {
        session: String,
    },
    ListSessions,
    ListTemplates {
        config: Option<PathBuf>,
    },
    ListProjects {
        config: Option<PathBuf>,
    },
    Doctor {
        fix: bool,
        config: Option<PathBuf>,
    },
    SaveProject {
        name: String,
        session: Option<String>,
        path: Option<PathBuf>,
        stdout: bool,
        force: bool,
        config: Option<PathBuf>,
    },
    Init {
        config: Option<PathBuf>,
    },
    Completions {
        shell: Shell,
        dir: Option<PathBuf>,
    },
    Man {
        dir: Option<PathBuf>,
    },
}

Variants



Select

Open the unified tmux session, project, and directory selector.

Fields

choose_template: bool
no_project_detect: bool
config: Option<PathBuf>


Connect

Create or reuse a tmux session for a directory.

Fields

path: PathBuf
template: Option<String>
session_name: Option<String>
config: Option<PathBuf>


Switch

Switch to or attach an existing tmux session.

Fields

session: String


ListSessions

Print current tmux session names.



ListTemplates

Print configured template names.

Fields

config: Option<PathBuf>


ListProjects

Print configured project entries.

Fields

config: Option<PathBuf>


Doctor

Validate runtime dependencies and basic environment state.

Fields

fix: bool
config: Option<PathBuf>


SaveProject

Capture a tmux session as a project file.

Fields

name: String
session: Option<String>
stdout: bool
force: bool
config: Option<PathBuf>


Init

Write an initial configuration file.

Fields

config: Option<PathBuf>


Completions

Generate shell completion scripts.

Fields

shell: Shell


Man

Generate man pages.

Fields